# vcs snapshot helper
_cdbs_scripts_path ?= /usr/lib/cdbs
_cdbs_rules_path ?= /usr/share/cdbs/1/rules
_cdbs_class_path ?= /usr/share/cdbs/1/class

ifndef _cdbs_rules_upstream_vcs
_cdbs_rules_upstream_vcs = 1

include $(_cdbs_rules_path)/buildvars.mk$(_cdbs_makefile_suffix)

DEB_UPSTREAM_VCS ?= git
sss:= $(shell echo $(DEB_UPSTREAM_VERSION) | grep -q '~' && echo '~' || echo '+')
rev = $(shell echo $(DEB_UPSTREAM_VERSION) | sed -ne 's/.*[+~]$(DEB_UPSTREAM_VCS)//;p')
rel:= $(shell echo $(DEB_UPSTREAM_VERSION) | sed -ne 's/^\([^~+]*\)[~+].*/\1/;p')
EXPORT_DIR       ?= ../tarballs
ORIG_SOURCE_BASE := $(DEB_SOURCE_PACKAGE)-$(DEB_UPSTREAM_VERSION)
ORIG_SOURCE      := $(EXPORT_DIR)/$(DEB_SOURCE_PACKAGE)_$(DEB_UPSTREAM_VERSION).orig.tar.xz

suggest-version:
	@if [ -d .svn ] || [ -d .git ]; then                                                                                   \
		echo "Current package version:  $(DEB_VERSION)";                                                                   \
		echo "Release version:          $(rel)";                                                                           \
		echo "Current upstream version: $(DEB_UPSTREAM_VERSION)";                                                          \
		echo "Suggested version:        $($(DEB_UPSTREAM_VCS)-suggest-version)";                                           \
	fi

git-suggest-version = $(shell                                                                                              \
	if [ -d .git ]; then                                                                                                   \
		vcstag=$$(git log --date=short --pretty="format:%ad %h" -n 1 | sed -e 's/-//g; s/ /$(sss)git/g;');                 \
		echo "$(rel)$(sss)$$vcstag";                                                                                       \
	fi)

svn-suggest-version = $(shell                                                                                              \
	if [ -d .svn ]; then                                                                                                   \
		vcstag=$$(svn log -l1 | sed -ne '/^r[0-9]\+/ {s/-//g;s/^r\([0-9]\+\) . [^ ]\+ . \([^ ]\+\).*/\2$(sss)svn\1/;p }'); \
		echo "$(rel)$(sss)$$vcstag";                                                                                       \
	fi)

$(ORIG_SOURCE):
	$($(DEB_UPSTREAM_VCS)-update-orig)
	@touch $@

update-orig: $(ORIG_SOURCE)

git-update-orig = $(shell                                                                                                  \
	if git status >/dev/null 2>/dev/null; then                                                                             \
		echo "Creating $(ORIG_SOURCE) from git-$(rev)" >&2;                                                                \
		git archive --prefix=$(ORIG_SOURCE_BASE)/ $(rev) | xz -9e > $(ORIG_SOURCE);                                        \
	else                                                                                                                   \
		echo "This is not a GIT working copy." >&2;                                                                        \
	fi)

svn-update-orig = $(shell                                                                                                  \
	if [ -d .svn ]; then                                                                                                   \
		echo "Creating $(ORIG_SOURCE) from svn-$(rev)" >&2;                                                                \
		mkdir -p svn-export;                                                                                               \
		svn export -r $(rev) . svn-export/$(ORIG_SOURCE_BASE) >/dev/null &&                                                \
			tar c -C svn-export $(ORIG_SOURCE_BASE) | xz -9e > $(ORIG_SOURCE);                                             \
		rm -rf svn-export;                                                                                                 \
	else                                                                                                                   \
		echo "This is not a SVN working copy." >&2;                                                                        \
	fi)

DEB_PHONY_RULES += suggest-version update-orig

endif
